#pragma once

// @generated by torchgen/gen.py from Function.h

#include <ATen/Context.h>
#include <ATen/DeviceGuard.h>
#include <ATen/TensorUtils.h>
#include <ATen/TracerMode.h>
#include <ATen/core/Generator.h>
#include <ATen/core/Reduction.h>
#include <ATen/core/Tensor.h>
#include <c10/core/Scalar.h>
#include <c10/core/Storage.h>
#include <c10/core/TensorOptions.h>
#include <c10/util/Deprecated.h>
#include <c10/util/Optional.h>



#include <ATen/ops/diag_backward_ops.h>

namespace at {


// aten::diag_backward(Tensor grad, SymInt[] input_sizes, int diagonal) -> Tensor
inline at::Tensor diag_backward(const at::Tensor & grad, at::IntArrayRef input_sizes, int64_t diagonal) {
    return at::_ops::diag_backward::call(grad, c10::fromIntArrayRef(input_sizes), diagonal);
}

// aten::diag_backward(Tensor grad, SymInt[] input_sizes, int diagonal) -> Tensor
inline at::Tensor diag_backward_symint(const at::Tensor & grad, c10::SymIntArrayRef input_sizes, int64_t diagonal) {
    return at::_ops::diag_backward::call(grad, input_sizes, diagonal);
}

}
